abacusai.nlp_chat_response — AbacusAI documentation

# abacusai.nlp_chat_response

## Classes

`NlpChatResponse` | A chat response from an LLM

## Module Contents

class abacusai.nlp_chat_response.NlpChatResponse(client, deploymentConversationId=None, messages=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A chat response from an LLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - deploymentConversationId (str) – The unique identifier of the deployment conversation.

    - messages (list) – The conversation messages in the chat.

  deployment_conversation_id = None
  messages = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict